==> tuia-payment-center-api-0.0.19-yzhao-20240914.081531-12-sources.jar: cn/tuia/payment/api/constants/SomeConstants.java <==
package cn.tuia.payment.api.constants;


import cn.tuia.payment.api.enums.PaymentChannelEnum;
import lombok.Data;

import java.util.Objects;

/**
 * @author lizhiheng
 */
@Data
public class SomeConstants {
    private static final String LD_RELEASING_NUM_CONFIG = "%s_ld_releasing_num_config";
    private static final String LD_RELEASING_NUM_CONFIG_V2 = "%s_ld_releasing_num_config_v2";
    private static final String LD_REMAINING_NUM_CONFIG = "%s_ld_remaining_num_config";
    private static final String LD_PULL_UP_RATE_CONFIG = "%s_ld_pull_up_rate_config";
    private static final String LD_RELEASING_UPDATE_CONFIG = "ld_releasing_update_config";

    private static final String UP_RELEASING_NUM_CONFIG = "%s_up_releasing_num_config";
    private static final String UP_RELEASING_NUM_CONFIG_V2 = "%s_up_releasing_num_config_v2";
    private static final String UP_REMAINING_NUM_CONFIG = "%s_up_remaining_num_config";
    private static final String UP_PULL_UP_RATE_CONFIG = "%s_up_pull_up_rate_config";
    private static final String UP_RELEASING_UPDATE_CONFIG = "up_releasing_update_config";

    // 时段配置 {poolId}_xx
    private static final String POOL_TIME_PERIOD_CONFIG = "%s_pool_time_period_config";
    // 在投自动更新配置 {poolId}_xx
    private static final String POOL_RELEASING_UPDATE_CONFIG = "%s_pool_releasing_update_config";
    // 在投子商户余量监控告警 配置 {poolId}_xx
    private static final String POOL_REMAINING_NUM_CONFIG_V2 = "%s_remaining_num_configV2";
    // 养号策略 配置  {poolId}_xx
    private static final String POOL_ACCOUNT_NURTURING_CONFIG = "%s_account_nurturing_config";


    /**
     * 养号策略 配置 key
     *
     * @param poolId
     * @return
     */
    public static String getPoolAccountNurturingConfig(Long poolId) {
        return String.format(POOL_ACCOUNT_NURTURING_CONFIG, poolId);
    }


    /**
     * 商户池 在投池自动更新 配置
     *
     * @param poolId
     * @return
     */
    public static String getPoolReleasingUpdateConfig(Integer channel, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return Objects.equals(channel, PaymentChannelEnum.LIANDONG.getCode()) ? LD_RELEASING_UPDATE_CONFIG :
                    Objects.equals(channel, PaymentChannelEnum.UNION_PAY.getCode()) ? UP_RELEASING_UPDATE_CONFIG :
                            null;
        }
        return String.format(POOL_RELEASING_UPDATE_CONFIG, poolId);
    }

    public static String getLdReleasingNumConfig(String merId) {
        return String.format(LD_RELEASING_NUM_CONFIG, merId);
    }

    public static String getUpReleasingNumConfig(String merId) {
        return String.format(UP_RELEASING_NUM_CONFIG, merId);
    }




    /* ******在投子商户余量监控告警 配置key start ******/

    /**
     * 在投子商户余量监控告警 配置key
     *
     * @param channel
     * @param type
     * @param poolId
     * @return
     */
    public static String getRemainingNumConfigV2(Integer channel, String type, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return Objects.equals(channel, PaymentChannelEnum.LIANDONG.getCode()) ? getLdRemainingNumConfig(type) :
                    Objects.equals(channel, PaymentChannelEnum.UNION_PAY.getCode()) ? getUpRemainingNumConfig(type) :
                            null;
        } else {
            return String.format(POOL_REMAINING_NUM_CONFIG_V2, poolId);
        }
    }

    public static String getLdRemainingNumConfig(String merId) {
        return String.format(LD_REMAINING_NUM_CONFIG, merId);
    }

    public static String getUpRemainingNumConfig(String merId) {
        return String.format(UP_REMAINING_NUM_CONFIG, merId);
    }
    /* ******在投子商户余量监控告警 配置key end ******/

    /* ***** 时间段配置 start ******/

    /**
     * 获取 商户池 时间段配置key
     */
    public static String getReleasingNumConfigKey(Integer paymentChannel, String code, Long poolId) {
        return Objects.equals(paymentChannel, PaymentChannelEnum.LIANDONG.getCode()) ? SomeConstants.getLdReleasingNumConfigV2(code, poolId) :
                Objects.equals(paymentChannel, PaymentChannelEnum.UNION_PAY.getCode()) ? SomeConstants.getUpReleasingNumConfigV2(code, poolId) :
                        null;
    }

    /**
     * 银联 时间段配置key
     *
     * @param merId
     * @param poolId
     * @return
     */
    private static String getUpReleasingNumConfigV2(String merId, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return String.format(UP_RELEASING_NUM_CONFIG_V2, merId);
        } else {
            return getPoolTimePeriodConfig(poolId);
        }
    }

    /**
     * 联动 时间段配置key
     *
     * @param merId
     * @param poolId
     * @return
     */
    private static String getLdReleasingNumConfigV2(String merId, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return String.format(LD_RELEASING_NUM_CONFIG_V2, merId);
        } else {
            return getPoolTimePeriodConfig(poolId);
        }
    }

    /**
     * 商户池 时间段 配置
     *
     * @param poolId
     * @return
     */
    private static String getPoolTimePeriodConfig(Long poolId) {
        return String.format(POOL_TIME_PERIOD_CONFIG, poolId);
    }

    /* ***** 时间段配置 end ******/


    public static String getLdPullUpRateConfig(String merId) {
        return String.format(LD_PULL_UP_RATE_CONFIG, merId);
    }

    public static String getUpPullUpRateConfig(String merId) {
        return String.format(UP_PULL_UP_RATE_CONFIG, merId);
    }

}

==> tuia-payment-center-api-0.0.26-yzhao-20241015.062944-17-sources.jar: cn/tuia/payment/api/constants/SomeConstants.java <==
package cn.tuia.payment.api.constants;


import cn.tuia.payment.api.enums.PaymentChannelEnum;
import lombok.Data;

import java.util.Objects;

/**
 * @author lizhiheng
 */
@Data
public class SomeConstants {
    private static final String LD_RELEASING_NUM_CONFIG = "%s_ld_releasing_num_config";
    private static final String LD_RELEASING_NUM_CONFIG_V2 = "%s_ld_releasing_num_config_v2";
    private static final String LD_REMAINING_NUM_CONFIG = "%s_ld_remaining_num_config";
    private static final String LD_PULL_UP_RATE_CONFIG = "%s_ld_pull_up_rate_config";
    private static final String LD_RELEASING_UPDATE_CONFIG = "%s_ld_releasing_update_config";

    private static final String UP_RELEASING_NUM_CONFIG = "%s_up_releasing_num_config";
    private static final String UP_RELEASING_NUM_CONFIG_V2 = "%s_up_releasing_num_config_v2";
    private static final String UP_REMAINING_NUM_CONFIG = "%s_up_remaining_num_config";
    private static final String UP_PULL_UP_RATE_CONFIG = "%s_up_pull_up_rate_config";
    private static final String UP_RELEASING_UPDATE_CONFIG = "%s_up_releasing_update_config";

    // 时段配置 {poolId}_xx
    private static final String POOL_TIME_PERIOD_CONFIG = "%s_pool_time_period_config";
    // 在投自动更新配置 {poolId}_xx
    private static final String POOL_RELEASING_UPDATE_CONFIG = "%s_pool_releasing_update_config";
    // 在投子商户余量监控告警 配置 {poolId}_xx
    private static final String POOL_REMAINING_NUM_CONFIG_V2 = "%s_remaining_num_configV2";
    // 养号策略 配置  {poolId}_xx
    private static final String POOL_ACCOUNT_NURTURING_CONFIG = "%s_account_nurturing_config";

    private static final String PULL_UP_RATE_CONFIG = "%s_%s_pull_up_rate_config";

    /**
     * 养号策略 配置 key
     *
     * @param poolId
     * @return
     */
    public static String getPoolAccountNurturingConfig(Long poolId) {
        return String.format(POOL_ACCOUNT_NURTURING_CONFIG, poolId);
    }


    /**
     * 商户池 在投池自动更新 配置
     *
     * @param poolId
     * @return
     */
    public static String getPoolReleasingUpdateConfig(Integer channel, Long poolId, String type) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return Objects.equals(channel, PaymentChannelEnum.LIANDONG.getCode()) ? String.format(LD_RELEASING_UPDATE_CONFIG, type) :
                    Objects.equals(channel, PaymentChannelEnum.UNION_PAY.getCode()) ? String.format(UP_RELEASING_UPDATE_CONFIG, type) :
                            null;
        }
        return String.format(POOL_RELEASING_UPDATE_CONFIG, poolId);
    }

    public static String getLdReleasingNumConfig(String merId) {
        return String.format(LD_RELEASING_NUM_CONFIG, merId);
    }

    public static String getUpReleasingNumConfig(String merId) {
        return String.format(UP_RELEASING_NUM_CONFIG, merId);
    }




    /* ******在投子商户余量监控告警 配置key start ******/

    /**
     * 在投子商户余量监控告警 配置key
     *
     * @param channel
     * @param type
     * @param poolId
     * @return
     */
    public static String getRemainingNumConfigV2(Integer channel, String type, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return Objects.equals(channel, PaymentChannelEnum.LIANDONG.getCode()) ? getLdRemainingNumConfig(type) :
                    Objects.equals(channel, PaymentChannelEnum.UNION_PAY.getCode()) ? getUpRemainingNumConfig(type) :
                            null;
        } else {
            return String.format(POOL_REMAINING_NUM_CONFIG_V2, poolId);
        }
    }

    public static String getLdRemainingNumConfig(String merId) {
        return String.format(LD_REMAINING_NUM_CONFIG, merId);
    }

    public static String getUpRemainingNumConfig(String merId) {
        return String.format(UP_REMAINING_NUM_CONFIG, merId);
    }
    /* ******在投子商户余量监控告警 配置key end ******/

    /* ***** 时间段配置 start ******/

    /**
     * 获取 商户池 时间段配置key
     */
    public static String getReleasingNumConfigKey(Integer paymentChannel, String code, Long poolId) {
        return Objects.equals(paymentChannel, PaymentChannelEnum.LIANDONG.getCode()) ? SomeConstants.getLdReleasingNumConfigV2(code, poolId) :
                Objects.equals(paymentChannel, PaymentChannelEnum.UNION_PAY.getCode()) ? SomeConstants.getUpReleasingNumConfigV2(code, poolId) :
                        getPoolTimePeriodConfig(poolId);
    }

    /**
     * 银联 时间段配置key
     *
     * @param merId
     * @param poolId
     * @return
     */
    private static String getUpReleasingNumConfigV2(String merId, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return String.format(UP_RELEASING_NUM_CONFIG_V2, merId);
        } else {
            return getPoolTimePeriodConfig(poolId);
        }
    }

    /**
     * 联动 时间段配置key
     *
     * @param merId
     * @param poolId
     * @return
     */
    private static String getLdReleasingNumConfigV2(String merId, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return String.format(LD_RELEASING_NUM_CONFIG_V2, merId);
        } else {
            return getPoolTimePeriodConfig(poolId);
        }
    }

    /**
     * 商户池 时间段 配置
     *
     * @param poolId
     * @return
     */
    private static String getPoolTimePeriodConfig(Long poolId) {
        return String.format(POOL_TIME_PERIOD_CONFIG, poolId);
    }

    /* ***** 时间段配置 end ******/


    public static String getLdPullUpRateConfig(String merId) {
        return String.format(LD_PULL_UP_RATE_CONFIG, merId);
    }

    public static String getUpPullUpRateConfig(String merId) {
        return String.format(UP_PULL_UP_RATE_CONFIG, merId);
    }

    public static String getPullUpRateConfig(Integer channel, String type) {
        // 银联 联动 还是用老的配置，其他行业走新的配置 channel_type_xxx
        if (Objects.equals(channel, PaymentChannelEnum.LIANDONG.getCode())) {
            return getLdPullUpRateConfig(type);
        } else if (Objects.equals(channel, PaymentChannelEnum.UNION_PAY.getCode())) {
            return getUpPullUpRateConfig(type);
        } else {
            return String.format(PULL_UP_RATE_CONFIG, channel, type);
        }
    }

}
